@@ -98,10 +98,8 @@ def add_toctree_data(app, pagename, templatename, context, doctree):
             entry_docname = tree['entries'][0][1]
             toctrees = app.env.toc_dict[entry_docname]['toctrees']
 
-            if toctrees:
-                # FIXME
-                assert len(toctrees) == 1, "Press: Not supported more then one toctree on nested toctree"
-                tree = toctrees[0]
+            for tree in toctrees:
+                pass
 
         current0 = False # same page might have multiple tocs
 
